==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage invalid" : "Nieprawidłowy magazyn",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "Recent" : "Ostatnie",
    "File could not be found" : "Nie można odnaleźć pliku",
    "Home" : "Start",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć folderu „{dir}”",
    "Upload cancelled." : "Wysyłanie anulowane.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Folder docelowy \"{dir}\" już nie istnieje",
    "Not enough free space" : "Za mało wolnego miejsca",
    "Uploading …" : "Wysyłanie...",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Folder docelowy już nie istnieje",
    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Move or copy" : "Przenieś lub kopiuj",
    "Target folder" : "Folder docelowy",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
    "Could not move \"{file}\", target exists" : "Nie można przenieść „{file}” - plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć folderu „{dir}”, ponieważ już istnieje.",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku „{fileName}”.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych folderach dla {tag}{filter}{endtag}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca dla {owner}, pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasujący '{filter}'","pasujące '{filter}'","pasujących '{filter}'","pasujących '{filter}'"],
    "View in folder" : "Zobacz w katalogu",
    "Copied!" : "Skopiowano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj link bezpośredni (działa tylko dla użytkowników, którzy mają dostęp do pliku/folderu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubione",
    "New folder" : "Nowy folder",
    "Upload file" : "Wyślij plik",
    "Not favorited" : "Wyłączone z ulubionych",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote user\"" : "\"użytkownik zdalny\"",
    "You created {file}" : "Utworzy‭łeś {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{file} was created in a public folder" : "{file} został utworzony w folderze publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z Twoich <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Plik lub folder został <strong>zmieniony lub <strong>zastąpiony",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o utworzeniu i zmianach do swoich <strong>ulubionych plików</strong> <em>(Tylko w strumieniu aktywności)</em>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został  <strong>przywrócony</strong>",
    "Unlimited" : "Bez limitu",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "File handling" : "Zarządzanie plikami",
    "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
    "max. possible: " : "maks. możliwy:",
    "Save" : "Zapisz",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Z PHP-FPM zastosowanie zmian może zająć 5 minut.",
    "Missing permissions to edit from here." : "Brakuje uprawnień do edycji.",
    "%s of %s used" : "Wykorzystano %s z %s",
    "%s used" : "Wykorzystane: %s",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "Cancel upload" : "Anuluj wysyłanie",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites yet" : "Brak jeszcze ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared with others" : "Udostępnione przez Ciebie",
    "Shared by link" : "Udostępnione przez link",
    "Tags" : "Tagi",
    "Deleted files" : "Usunięte pliki",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "Uploading..." : "Wysyłanie....",
    "..." : "...",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["Pozostała {hours}:{minutes}:{seconds} godzina","Pozostało {hours}:{minutes}:{seconds} godzin","Pozostało {hours}:{minutes}:{seconds} godzin"],
    "{hours}:{minutes}h" : "{hours}h:{minutes}m",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["Pozostała {minutes}:{seconds} minuta","Pozostało {minutes}:{seconds} minut","Pozostało {minutes}:{seconds} minut"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}min.",
    "_{seconds} second left_::_{seconds} seconds left_" : ["Pozostała {seconds} sekunda","Pozostało {seconds} sekund","Pozostało {seconds} sekund"],
    "{seconds}s" : "{seconds} s",
    "Any moment now..." : "Jeszcze chwilę...",
    "Soon..." : "Wkrótce...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "Move" : "Przenieś",
    "Copy local link" : "Skopiuj link lokalny",
    "Folder" : "Folder",
    "Upload" : "Wyślij",
    "A new file or folder has been <strong>deleted</strong>" : "Nowy plik lub folder został <strong>usunięty </strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nowy plik lub folder został <strong>przywrócony</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "No favorites" : "Brak ulubionych"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage invalid" : "Nieprawidłowy magazyn",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "Recent" : "Ostatnie",
    "File could not be found" : "Nie można odnaleźć pliku",
    "Home" : "Start",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć folderu „{dir}”",
    "Upload cancelled." : "Wysyłanie anulowane.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Folder docelowy \"{dir}\" już nie istnieje",
    "Not enough free space" : "Za mało wolnego miejsca",
    "Uploading …" : "Wysyłanie...",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Folder docelowy już nie istnieje",
    "Error when assembling chunks, status code {status}" : "Błąd podczas łączenia fragmentów, kod statusu {status}",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Move or copy" : "Przenieś lub kopiuj",
    "Copy" : "Kopiuj",
    "Target folder" : "Folder docelowy",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
    "Could not move \"{file}\", target exists" : "Nie można przenieść „{file}” - plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można przenieść \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Nie można skopiować \"{file}\", plik już istnieje",
    "Could not copy \"{file}\"" : "Nie można skopiować \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopiowano {origin} wewnątrz {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopiowano {origin} oraz {nbfiles} innych plików wewnątrz {destination}",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć folderu „{dir}”, ponieważ już istnieje.",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku „{fileName}”.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych folderach dla {tag}{filter}{endtag}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Zmodyfikowany",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "{used} of {quota} used" : "Wykorzystane {used} z {quota}",
    "{used} used" : "Wykorzystane {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" jest niedozwolony w nazwie pliku.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" jest niedozwolony",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca dla {owner}, pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasujący '{filter}'","pasujące '{filter}'","pasujących '{filter}'","pasujących '{filter}'"],
    "View in folder" : "Zobacz w katalogu",
    "Copied!" : "Skopiowano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj link bezpośredni (działa tylko dla użytkowników, którzy mają dostęp do pliku/folderu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubione",
    "New folder" : "Nowy folder",
    "Upload file" : "Wyślij plik",
    "Not favorited" : "Wyłączone z ulubionych",
    "Remove from favorites" : "Usuń z ulubionych",
    "Add to favorites" : "Dodaj do ulubionych",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote user\"" : "\"użytkownik zdalny\"",
    "You created {file}" : "Utworzy‭łeś {file}",
    "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{user} created an encrypted file in {file}" : "{user} utworzył zaszyfrowany plik w {file}",
    "{file} was created in a public folder" : "{file} został utworzony w folderze publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "You changed an encrypted file in {file}" : "Zmieniłeś zaszyfrowany plik w {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmienił zaszyfrowany plik w {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "You deleted an encrypted file in {file}" : "Usunąłeś zaszyfrowany plik w {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "{user} deleted an encrypted file in {file}" : "{user} usunął zaszyfrowany plik w {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z Twoich <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Plik lub folder został <strong>zmieniony lub <strong>zastąpiony",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o utworzeniu i zmianach do swoich <strong>ulubionych plików</strong> <em>(Tylko w strumieniu aktywności)</em>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został  <strong>przywrócony</strong>",
    "Unlimited" : "Bez limitu",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "File handling" : "Zarządzanie plikami",
    "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
    "max. possible: " : "maks. możliwy:",
    "Save" : "Zapisz",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Z PHP-FPM zastosowanie zmian może zająć 5 minut.",
    "Missing permissions to edit from here." : "Brakuje uprawnień do edycji.",
    "%s of %s used" : "Wykorzystano %s z %s",
    "%s used" : "Wykorzystane: %s",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "Cancel upload" : "Anuluj wysyłanie",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Wysyłany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites yet" : "Brak jeszcze ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared with others" : "Udostępnione przez Ciebie",
    "Shared by link" : "Udostępnione przez link",
    "Tags" : "Tagi",
    "Deleted files" : "Usunięte pliki",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "Move" : "Przenieś",
    "A new file or folder has been <strong>deleted</strong>" : "Nowy plik lub folder został <strong>usunięty</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nowy plik lub folder został <strong>odtworzony</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj swojego adresu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">aby mieć dostęp do Plików przez WebDAV"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
